/************************************************************
Copyright (C) 2005 Masahiko SAWAI All Rights Reserved. 
************************************************************/
package sdl4gcj.mixer;

import sdl4gcj.SDLException;
import java.io.File;


public class Music implements MixerConstants
{
	// instance variables
	protected gnu.gcj.RawData implementation = null;

	// class methods

	public static native Music loadMUS(String filePath);

	public static Music loadMUS(File file)
	{
		return loadMUS(file.getAbsolutePath());
	}

	// constructors
	protected Music()
	{
	}

	// instance methods
	public native void freeMusic();

	public native int getMusicType();

	protected void finalize() throws Throwable
	{
		this.freeMusic();
		super.finalize();
	}
}

